package cn.minbb.InterfaceTest;

import android.os.Bundle;
import android.os.Environment;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AlertDialog;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.app.AppCompatDelegate;
import android.util.Log;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.android.volley.Request;
import com.android.volley.toolbox.StringRequest;
import com.joanzapata.iconify.widget.IconTextView;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import cn.minbb.InterfaceTest.ctrl.App;
import cn.minbb.InterfaceTest.ctrl.PermissionManager;
import cn.minbb.InterfaceTest.views.LoginActivity;
import cn.minbb.InterfaceTest.views.MainActivity;
import cn.minbb.InterfaceTest.views.RegisterActivity;
import okhttp3.Call;
import okhttp3.Callback;
import okhttp3.OkHttpClient;
import okhttp3.Response;

public class EntranceActivity extends AppCompatActivity {

    @BindView(R.id.dataInterface)
    Button dataInterface;
    @BindView(R.id.registerInterface)
    Button registerInterface;
    @BindView(R.id.loginInterface)
    Button loginInterface;
    @BindView(R.id.serverStatus)
    TextView serverStatus;
    @BindView(R.id.serverStatusRefresh)
    IconTextView serverStatusRefresh;

    static {
        AppCompatDelegate.setCompatVectorFromResourcesEnabled(true);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_entrance);
        ButterKnife.bind(this);
        App.setupActionBar(this);
        new PermissionManager(this).addPermission("").checkAndRequestPermissions();
        testServerStatus();
    }

    @OnClick({R.id.dataInterface, R.id.registerInterface, R.id.loginInterface, R.id.downloadFile, R.id.serverStatusRefresh})
    public void onViewClicked(View view) {
        switch (view.getId()) {
            case R.id.dataInterface:
                MainActivity.start(EntranceActivity.this);
                break;
            case R.id.registerInterface:
                RegisterActivity.start(EntranceActivity.this);
                break;
            case R.id.loginInterface:
                LoginActivity.start(EntranceActivity.this);
                break;
            case R.id.downloadFile:
                String url = "https://files-1252373323.cos.ap-beijing.myqcloud.com/Iconify.apk";
                OkHttpClient client = new OkHttpClient();
                okhttp3.Request request = new okhttp3.Request.Builder().get().url(url).build();
                Call call = client.newCall(request);
                call.enqueue(new Callback() {
                    @Override
                    public void onFailure(Call call, IOException e) {
                        e.printStackTrace();
                        Log.e("more", "onFailure: " + e);
                    }

                    @Override
                    public void onResponse(Call call, Response response) throws IOException {
                        //  String dirName = Environment.getExternalStorageDirectory().getAbsolutePath() + "/LungFile";
                        String dirName = Environment.getExternalStorageDirectory().getAbsolutePath() + "/AAAFile";
                        File file = new File(dirName);
                        if (!file.exists()) {
                            file.mkdir();
                        }
                        File fileTxt = new File(dirName + "/Iconify.apk");
                        if (response != null) {
                            InputStream is = response.body().byteStream();
                            FileOutputStream fos = new FileOutputStream(fileTxt);
                            int len = 0;
                            byte[] buffer = new byte[2048];
                            while (-1 != (len = is.read(buffer))) {
                                fos.write(buffer, 0, len);
                            }
                            fos.flush();
                            fos.close();
                            is.close();
                        }
                        Log.d("more", "下载完毕 " + fileTxt.getAbsolutePath());
                    }
                });
                break;
            case R.id.serverStatusRefresh:
                testServerStatus();
                break;
        }
    }

    // 检查服务器状态
    public void testServerStatus() {
        serverStatusRefresh.setText("{fa-refresh spin}");
        StringRequest serverStatusRequest = new StringRequest(Request.Method.GET,
                "http://218.28.14.168:8080/TKRCS/",
                s -> {
                    serverStatusRefresh.setText("{fa-refresh}");
                    serverStatus.setText("在线");
                    serverStatus.setTextColor(ContextCompat.getColor(this, android.R.color.holo_green_light));
                },
                volleyError -> {
                    serverStatusRefresh.setText("{fa-refresh}");
                    serverStatus.setText("离线");
                    serverStatus.setTextColor(ContextCompat.getColor(this, android.R.color.holo_red_light));
                });
        App.getRequestQueue().add(serverStatusRequest);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case android.R.id.home:
                exit();
                break;
            default:
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (keyCode == KeyEvent.KEYCODE_BACK) {
            exit();
        }
        return super.onKeyDown(keyCode, event);
    }

    private void exit() {
        AlertDialog.Builder builder = new AlertDialog.Builder(EntranceActivity.this);
        builder.setTitle("提示")
                .setMessage("退出系统测试？")
                .setPositiveButton("退出", (dialog, which) -> {
                    EntranceActivity.this.finish();
                })
                .setNegativeButton("取消", (dialog, which) -> {
                })
                .create().show();
    }
}
