package cn.minbb.InterfaceTest.views;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.support.design.widget.FloatingActionButton;
import android.support.design.widget.Snackbar;
import android.support.v7.app.AlertDialog;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.app.AppCompatDelegate;
import android.support.v7.widget.Toolbar;
import android.text.TextUtils;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.TextView;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.toolbox.StringRequest;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import cn.minbb.InterfaceTest.R;
import cn.minbb.InterfaceTest.controls.ClearTextInputEditText;
import cn.minbb.InterfaceTest.ctrl.App;

public class LoginActivity extends AppCompatActivity implements CompoundButton.OnCheckedChangeListener {

    @BindView(R.id.toolbar)
    Toolbar toolbar;
    @BindView(R.id.help)
    FloatingActionButton help;
    @BindView(R.id.userAccount)
    ClearTextInputEditText userAccount;
    @BindView(R.id.userName)
    ClearTextInputEditText userName;
    @BindView(R.id.userPassword)
    ClearTextInputEditText userPassword;
    @BindView(R.id.rememberPassword)
    CheckBox rememberPassword;
    @BindView(R.id.login)
    Button login;
    @BindView(R.id.registerAccount)
    TextView registerAccount;
    @BindView(R.id.losePassword)
    TextView losePassword;

    private ProgressDialog dialog;

    private boolean rememberPasswordIsChecked = false;

    static {
        AppCompatDelegate.setCompatVectorFromResourcesEnabled(true);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_login);
        ButterKnife.bind(this);

        initView();
        setListener();
        loadData();
    }

    @Override
    protected void onRestart() {
        super.onRestart();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        App.getRequestQueue().cancelAll("login");
        if (dialog != null && dialog.isShowing()) {
            dialog.dismiss();
        }
    }

    public static void start(Context context) {
        context.startActivity(new Intent(context, LoginActivity.class));
    }

    private void initView() {
        toolbar.setNavigationIcon(R.drawable.ic_arrow_back_white_24dp);
        setSupportActionBar(toolbar);
    }

    private void setListener() {
        rememberPassword.setOnCheckedChangeListener(this);
    }

    private void loadData() {
    }

    private void attemptLogin() {
        // 重置错误为空
        userAccount.setError(null);
        userName.setError(null);
        userPassword.setError(null);

        // 获取登录表单账号与密码
        String userAccountText = userAccount.getText().toString();
        String userNameText = userName.getText().toString();
        String userPasswordText = userPassword.getText().toString();

        boolean cancel = false;
        ClearTextInputEditText focusView = null;

        // 检查 用户密码 是否有效
        if (TextUtils.isEmpty(userPasswordText) || !isUserPasswordValid(userPasswordText)) {
            userPassword.setError("用户密码不能为空");
            focusView = userPassword;
            cancel = true;
        }

        // 检查 用户全拼姓名 是否有效
        if (TextUtils.isEmpty(userNameText)) {
            userName.setError("用户全拼姓名不能为空");
            focusView = userName;
            cancel = true;
        }

        // 检查 用户账号 是否有效
        if (TextUtils.isEmpty(userAccountText) || !isUsernameValid(userAccountText)) {
            userAccount.setError("用户账号不能为空");
            focusView = userAccount;
            cancel = true;
        }

        if (cancel) {
            focusView.requestFocus();
            focusView.setShakeAnimation();
        } else {
            showProgress(true);
            toLogin(userAccountText, userNameText, userPasswordText);
        }
    }

    private boolean isUserPasswordValid(String passwordText) {
        return passwordText.length() >= 0;
    }

    private boolean isUsernameValid(String usernameText) {
        return usernameText.length() >= 1;
    }

    private void showProgress(boolean show) {
        if (dialog == null) {
            dialog = new ProgressDialog(this);
            dialog.setTitle("用户登录");
            dialog.setMessage("登录中······");
            dialog.setCancelable(false);
        }
        if (show) {
            dialog.show();
        } else {
            dialog.dismiss();
        }
    }

    private void toLogin(String userAccountText, String userNameText, String userPasswordText) {
        StringRequest loginRequest = new StringRequest(
                Request.Method.GET,
                "http://218.28.14.168:8080/TKRCS/mblogin.do?userAccount=" + userAccountText + "&userName=" + userNameText + "&userPassword=" + userPasswordText,
                s -> {
                    System.out.println("json = " + s);
                    ScrollingActivity.start(LoginActivity.this, s);
                    LoginActivity.this.finish();
                },
                volleyError -> {
                    showProgress(false);
                    Snackbar.make(toolbar.getRootView(), "登录失败，请稍后重试！", Snackbar.LENGTH_SHORT).show();
                    Toast.makeText(LoginActivity.this, volleyError.getMessage(), Toast.LENGTH_SHORT).show();
                }) {
        };
        loginRequest.setTag("login");
        App.getRequestQueue().add(loginRequest);
    }

    @OnClick({R.id.help, R.id.login, R.id.registerAccount, R.id.losePassword})
    public void onViewClicked(View view) {
        switch (view.getId()) {
            case R.id.help:
                AlertDialog.Builder builder = new AlertDialog.Builder(LoginActivity.this);
                builder.setTitle("帮助")
                        .setMessage("(*)号标识为必填项。")
                        .setPositiveButton("我知道啦", (dialog, which) -> {
                        })
                        .create().show();
                break;
            case R.id.login:
                attemptLogin();
                break;
            case R.id.registerAccount:
                RegisterActivity.start(this);
                break;
            case R.id.losePassword:
                Snackbar.make(toolbar.getRootView(), "密码丢失，请联系系统管理员", Snackbar.LENGTH_SHORT).show();
                break;
            default:
        }
    }

    @Override
    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
        switch (buttonView.getId()) {
            case R.id.rememberPassword:
                rememberPasswordIsChecked = isChecked;
                break;
            default:
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case android.R.id.home:
                finish();
                break;
            default:
        }
        return super.onOptionsItemSelected(item);
    }
}
